# Changelog

## `0.5.2` **breaking changes**
### Skip versions: {`0.5.0`, `0.5.1`}

**Required manual changes**

- _TypeScript_: Change `ReactDOM` and `TestUtils` to use require syntax. This is
  because `typings` is missing the `15.x.x` version of react type
  definitions.
- _TypeScript_: Update your component's `typings.json` to look like this:

```
{
    "name": "react-sapling-component",
    "globalDependencies": {
        "es6-shim": "registry:dt/es6-shim#0.31.2+20160602141504",
        "express": "registry:dt/express#4.0.0+20160317120654",
        "express-serve-static-core": "registry:dt/express-serve-static-core#0.0.0+20160625155614",
        "jest": "registry:dt/jest#0.9.0+20160425141105",
        "log4js": "registry:dt/log4js#0.0.0+20160608042355",
        "marked": "registry:dt/marked#0.0.0+20160325085301",
        "mustache": "registry:dt/mustache#0.8.2+20160316155526",
        "node": "registry:dt/node#6.0.0+20160621231320",
        "rx-lite": "registry:dt/rx-lite#0.0.0+20160623134935",
        "serve-static": "registry:dt/serve-static#0.0.0+20160606155157",
        "through": "registry:dt/through#0.0.0+20160317120654"
    },
    "dependencies": {
        "assertion-error": "registry:npm/assertion-error#1.0.0+20160422045008",
        "inquirer": "registry:npm/inquirer#1.0.0+20160427045422",
        "mime": "registry:npm/mime#1.3.0+20160423043021",
        "minimist": "registry:npm/minimist#1.0.0+20160229232932",
        "mkdirp": "registry:npm/mkdirp#0.5.0+20160222053049",
        "react": "registry:npm/react#15.0.1+20160601175240",
        "rimraf": "registry:npm/rimraf#2.5.0+20160211003958"
    }
}
```

## `0.4.8`

- Fix issues when errors that only appear when module is published to npm

## `0.4.7` (broken, skip this version)

- Fix bugs in 0.4.6 relating to the mounting of node modules from different
  sources.

## `0.4.6` (broken, skip this version)

- Fix bug where `.trash` dir isn't cleaned quick enough while running
  tasks in succession.
- Fix bug where different versions of the same package caused sapling
  to use the "dev" path when looking for node_modules vs. the components
  modules that it specified

**Required manual changes**

- In your `tsconfig.json`, change 'exclude' to look like this:

```
"exclude": [
    "node_modules",
    "dist",
    ".sapling-mounted-project",
    ".trash"
]
```


## `0.4.5`

- Fix duplicate errors with tsc with the `tsconfig.json` scaffold (See #77).
- User's jest configuration is now merged in with default configuration (See #76).

**Required manual changes**

- In your `tsconfig.json`, change 'exclude' to look like this:

```
"exclude": [
    "node_modules",
    "dist",
    ".sapling-mounted-project"
]
```

## `0.4.4`

- Allow the user to provide their own jest configuration (in package.json)

## `0.4.3`

- Fix issues with JS projects that require the jest babel preset.

**Required manual changes**

- Components no longer manage their own Jest configuraiton. Simply remove the `jest` field from your package.json

## `0.4.2`

- No longer rely on webpack for Jest tests. It will now use Jest preprocessor for all testing needs.
  - This means that you can nest tests anywhere in your project vs. one subdirectory

## `0.4.1`

- Bug fixes with TS projects

## `0.4.0` **breaking changes**

- By default allow JS imports in TS projects. (a3f0cff)
- Correctly transfer tsconfig when building (vs. using build in config). (53522d6)

**Required Manual Changes**

- Replaced the "main" path in `package.json` Change it to:

    ./dist/root.js

<sub>(previously it was `./dist/src/root.js`)</sub>

- Replaced Karma in favor of Jest. This was done to support component mocking.
  1. Create a new subdirectory called `__tests__` in your components `src`.
  2. Move all current test code into that directory. There isn't a need for a "test.tsx" file anymore & any file names are allowed to exist in this new directory that contain your test code.
  3. 😭 Update all tests from Mocha/Chai to use Jest tests (with expect).
  4. Copy this configuration into your package.json:

```
      "jest": {
        "verbose": true,
        "testDirectoryName": "__sapling_compiled_tests__",
        "unmockedModulePathPatterns": [
            "<rootDir>/node_modules/react/",
            "<rootDir>/node_modules/react-dom/",
            "<rootDir>/node_modules/react-addons-test-utils/"
        ]
    }
```

## `0.3.3`

- Automatically install typings if you're in a TypeScript project (see manual changes)
- Switch order of TS / JS (issue #66)
- Properly copy over .gitignore (#71)
- Removed requirement for `node` for npm run-scripts (#65)
- Simplified example scaffold code (#69)

**Required Manual Changes**

- Optional: Add `typings install && ...` on npm scripts build & start
for TypeScript projects.

- Optional: If you want to clean up your package.json, you can optionally remove
the `node ./node_modules/.bin/sapling <command>` and just replace
these instances with `sapling <command>`.

## `0.3.2`

- Fix npm package errors.

## `0.3.0` **breaking changes**

**Required Manual Changes**

- Update to Typings. After reinstalling sapling:

```
rm -rf node_modules typings tsd.json
npm install --save-dev react-sapling@0.3.0
npm install
```

Copy the `typings.json` configuration file from `scaffold/static/typescript/typings.json` and place it in your component root (where `tsd.json` used to live).

You will have to re-install any custom type definitions that you were using before. If you wish, take a look at the typings repository for updating from TSD.

## `0.2.5`

- New styles. (See #61)
- GitHub / git is no longer a requirement.

**Required Manual Changes**

- Add `.sapling-mounted-project` to your components `.gitignore` file.
- For TypeScript projects, change the current `sapling-mounted-project` lines to have a "." in front, i.e.:

```
".sapling-mounted-project/node_modules",
".sapling-mounted-project/typings"
```

## `0.2.4`

- Fix regression for testing with Karma
- bump babel-core version from 6.7.4 to 6.9.1
- add additional babel sugar for classes, #54
- builds will no longer run if eslint errors exist

## `0.2.3`

- Eslint for JavaScript components
  - PR: https://github.com/willowtreeapps/react-sapling/pull/52
- Multiple documentation support
  - Add a "docs" directory to your project with `*.md` files in it to dynamically add documentation to your project.
  - PR: https://github.com/willowtreeapps/react-sapling/pull/50

## `0.2.2`

**Required Manual Changes**

Create a .gitignore and a .npmignore that look like one ones here:

https://github.com/willowtreeapps/react-sapling/tree/01da5dd18ee9dc94546fca0cfa5c1c778558bf0a/src/scaffold/static/shared


Add clean and update the build script like this:

https://github.com/willowtreeapps/react-sapling/commit/a021d7c9f52a419dfaaca2f6402863d40a211c79

## `0.2.1`

No breaking changes or features introduced. Just a minor bug fix.

- Moved `document.title` to root.js vs docs.js for isomorphic apps

## `0.2.0` **breaking changes**

**Required Manual Changes**

- Update package.json

    Replace all build scripts with:

    ```js
    "build:lib-prod": "node ./node_modules/.bin/sapling build-lib-prod",
    "build:lib-docs": "node ./node_modules/.bin/sapling build-lib-docs",
    "build:bundle-docs": "node ./node_modules/.bin/sapling build-bundle-docs",
    "build": "npm run build:lib-prod && npm run build:bundle-docs",
    ```

## `0.1.2`

- Fixes regression in `0.0.27` that broke test cases.
- Better "ComponentName" description on `init` (issue #31)

**Required Manual Changes**

- Update TypeScript (`0.8.10`) & React (`15.1.0`):

```
➜ rm -rf node_modules/typescript
➜ rm -rf node_modules/react
➜ rm -rf node_modules/react-dom/
➜ rm -rf node_modules/react-addons-test-utils
➜ npm install
```

- Default `peerdependencies` for `react` & `react-dom` in your component's `package.json` should be updated to:

```
  "peerDependencies": {
      "react": "^0.14 || ^15.0.0-rc || ^15.0",
      "react-dom": "^0.14 || ^15.0.0-rc || ^15.0"
  },
```
