import React from 'react';
import ReadMeDocumentation from './readme-documentation';

const exampleStyle = require('!!raw!./src/example-style.scss');
const packageJson = require('!!raw!./package.json');
const packageData = JSON.parse(packageJson);

let exampleSrc = null;
let ComponentExample = null;

if (process.env.PROJECT_TYPE === 'typescript') {
    exampleSrc = require('!!raw!./src/example.tsx');
    ComponentExample = require('./src/example.tsx').default;
} else {
    exampleSrc = require('!!raw!./src/example.js');
    ComponentExample = require('./src/example.js').default;
}

export default class App extends React.Component {

    constructor(props) {
        super(props);

        this.state = { tab: 'readme' };
    }

    setTab(tab) {
        this.setState({ tab }, () => {
            window[`PR`][`prettyPrint`]();
        });
    }

    getSocialLinks() {
        const socialLinks = [];
        const repo = packageData.repository;

        if (repo && repo.type === 'git') {
            if (/github\.com/.test(repo.url)) {
                socialLinks.push(<li className="github" key="github-social">
                    <a href={packageData.homepage}>View on GitHub ↗</a>
                </li>);
            }
        }

        return socialLinks;
    }

    render() {
        return <div>
            <nav className="top-nav" role="navigation">
                <ul className="top-nav-list">
                    {this.getSocialLinks()}
                    <li className={`list-item ${this.state.tab === 'readme' ? 'active' : ''}`}
                        onClick={() => this.setTab('readme')}>documentation</li>
                    <li className={`list-item ${this.state.tab === 'example' ? 'active' : ''}`}
                        onClick={() => this.setTab('example')}>example</li>
                    <li className={`list-item ${this.state.tab === 'package' ? 'active' : ''}`}
                        onClick={() => this.setTab('package')}>package.json</li>
                </ul>
            </nav>
            <div className="main" role="main">
                {this.state.tab === 'readme' && <ReadMeDocumentation />}
                {this.state.tab === 'example' && <section>
                <h1>Component Example</h1>
                <div className="component-container">
                    <ComponentExample />
                </div>
                <h2>Example Src</h2>
                <pre className="pre-container prettyprint linenums lang-js">
                    {exampleSrc}
                </pre>
                <h2>Styles Used</h2>
                <div>
                    <pre className="pre-container prettyprint linenums lang-css">
                        {exampleStyle}
                    </pre>
                </div>
                </section>}
                {this.state.tab === 'package' && <pre className="pre-container linenums prettyprint lang-js">
                    {packageJson}
                </pre>}
            </div>
        </div>;
    }
}
