import React, { Component } from 'react';
import marked from 'marked';

const readmeMd = require('!!raw!./README.md');
const titleizeKey = (key) => {
    return key.replace('.md', '').replace(/[^\w\s]/g, '')
};

let markupModules = [];
let subDocuments = [];
try {
    const requireContext = require.context("!!raw!../docs", !1, /\.md$/);
    markupModules = requireContext.keys().map(requireContext);
    subDocuments = requireContext.keys().map(titleizeKey);
} catch(err) {}

const allMarkupDocs = [readmeMd].concat(markupModules);
const allMarkupTitles = ['README'].concat(subDocuments);

function createReadmeMarkup(markupFile): { __html: string } {
    return { __html: marked(markupFile) };
};

export default class ReadMeDocumentation extends Component {
    constructor(props) {
        super(props);
        this.setSelectedDocument = this.setSelectedDocument.bind(this);
        this.state = {
            selectedDocument: 0,
        };
    }

    setSelectedDocument(docIdx) {
        this.setState({
            selectedDocument: docIdx,
        });
    }

    getSelectedClass(index) {
        const { selectedDocument } = this.state;
        return `${index === selectedDocument ? 'active' : ''} doc-nav-item`;
    }

    renderSelectionBox() {
        return allMarkupTitles.length > 1 ? (<ul className='doc-nav'>
            {allMarkupTitles.map((doc, idx) => {
                return (<li
                    key={`doc-${idx}`}
                    className={this.getSelectedClass(idx)}
                    onClick={() => this.setSelectedDocument(idx)}
                >
                    {doc}
                </li>);
            })}
        </ul>) : null;
    }

    renderSelectedDocument() {
        const { selectedDocument } = this.state;
        const title = allMarkupTitles[selectedDocument];
        const shownTitle = (title !== 'README') ? <h1>{title}</h1> : '';
        const markupFile = allMarkupDocs[selectedDocument];
        return (<section>
            {shownTitle}
            <div dangerouslySetInnerHTML={createReadmeMarkup(markupFile)}/>
        </section>);
    }
    render() {
        return (<div>
            {this.renderSelectionBox()}
            {this.renderSelectedDocument()}
        </div>);
    }
}
