const path = require('path');
const combineLoaders = require('webpack-combine-loaders');
const webpack = require('webpack');

// Remember that we are currently in a symlinked container
// directory. The _true_ project root is one level up.
const PROJECT_ROOT = path.join(__dirname, '..');
// For development purposes
const OUR_MODULES = path.join(PROJECT_ROOT, 'node_modules', 'react-sapling', 'node_modules');

module.exports = {
    bail: true,
    devtool: 'source-map',
    entry: [path.join(__dirname, 'root.js')],
    plugins: [
        new webpack.optimize.OccurrenceOrderPlugin(),
        new webpack.DefinePlugin({
            'process.env': {
                NODE_ENV: JSON.stringify('production'),
                PROJECT_TYPE: JSON.stringify('javascript')
            }
        })
    ],
    module: {
        loaders: [{
            test: /\.jsx?$/,
            incude: path.join(__dirname, 'src'),
            exclude: /node_modules/,
            loader: combineLoaders([
                {
                    loader: 'react-hot'
                },
                {
                    loader: 'babel',
                    query: {
                        presets: [
                            require.resolve('babel-preset-es2015'),
                            require.resolve('babel-preset-react'),
                            require.resolve('babel-preset-stage-0')
                        ],
                        plugins: [
                            require.resolve('babel-plugin-syntax-class-properties'),
                            require.resolve('babel-plugin-transform-class-properties')
                        ]
                    }
                }
            ])
        }, {
            test: /\.scss$/,
            loaders: ['style', 'css', 'sass']
        }]
    },
    output: {
        filename: 'root.js',
        path: path.join(PROJECT_ROOT, 'dist', 'docs', 'static'),
        publicPath: '/static/'
    },
    resolve: {
        root: [ __dirname ],
        fallback: OUR_MODULES,
        extensions: ['', '.jsx', '.js', '.tsx', '.ts']
    },
    resolveLoader: {
        root: path.join(__dirname, 'node_modules'),
        fallback: OUR_MODULES
    }
};
