const webpack = require('webpack');
const path = require('path');
const combineLoaders = require('webpack-combine-loaders');

// Remember that we are currently in a symlinked container
// directory. The _true_ project root is one level up.
const PROJECT_ROOT = path.join(__dirname, '..');
// For development purposes
const OUR_MODULES = path.join(PROJECT_ROOT, 'node_modules', 'react-sapling', 'node_modules');

module.exports = {
    devtool: 'source-map',
    bail: true,
    entry: [path.join(__dirname, 'src', 'root.js')],
    externals: {
        'react': 'react',
        'react-dom': 'react-dom'
    },
    eslint: {
        failOnWarning: true,
        failOnError: true
    },
    module: {
        preLoaders: [{
            test: /\.jsx?$/,
            loader:  'eslint',
            include: path.join(PROJECT_ROOT, 'src'),
            exclude: /node_modules/
        }],
        loaders: [{
            test: /\.jsx?$/,
            incude: path.join(__dirname, 'src'),
            exclude: /node_modules/,
            loader: combineLoaders([
                {
                    loader: 'babel',
                    query: {
                        presets: [
                            require.resolve('babel-preset-es2015'),
                            require.resolve('babel-preset-react'),
                            require.resolve('babel-preset-stage-0')
                        ],
                        plugins: [
                            require.resolve('babel-plugin-syntax-class-properties'),
                            require.resolve('babel-plugin-transform-class-properties')
                        ]
                    }
                }
            ])
        }]
    },
    plugins: [
        new webpack.optimize.OccurrenceOrderPlugin(),
        new webpack.DefinePlugin({
            'process.env': {
                NODE_ENV: JSON.stringify('production'),
                PROJECT_TYPE: JSON.stringify('javascript')
            }
        })
    ],
    output: {
        filename: 'root.js',
        path: path.join(PROJECT_ROOT, 'dist'),
        publicPath: '/static/',
        library: 'SaplingComponent',
        libraryTarget: 'commonjs2'
    },
    resolve: {
        root: [ __dirname ],
        fallback: OUR_MODULES,
        extensions: ['', '.jsx', '.js']
    },
    resolveLoader: {
        root: path.join(__dirname, 'node_modules'),
        fallback: OUR_MODULES
    }
};
