const webpack = require('webpack');
const path = require('path');
const combineLoaders = require('webpack-combine-loaders');

// Remember that we are currently in a symlinked container
// directory. The _true_ project root is one level up.
const PROJECT_ROOT = path.join(__dirname, '..');
// For development purposes
const OUR_MODULES = path.join(PROJECT_ROOT, 'node_modules', 'react-sapling', 'node_modules');

module.exports = {
    bail: true,
    devtool: 'source-map',
    externals: {
        'react': 'react',
        'react-dom': 'react-dom'
    },
    tslint: {
        emitErrors: true,
        failOnHint: true
    },
    plugins: [
        new webpack.optimize.OccurrenceOrderPlugin(),
        new webpack.DefinePlugin({
            'process.env': {
                NODE_ENV: JSON.stringify('production'),
                PROJECT_TYPE: JSON.stringify('typescript')
            }
        })
    ],
    entry: [path.join(__dirname, 'src', 'root.tsx')],
    module: {
        preLoaders: [{
            test: /\.tsx?$/,
            loader: 'tslint',
            include: path.join(PROJECT_ROOT, 'src'),
            exclude: /node_modules/
        }],
        loaders: [{
            test: /\.tsx?$/,
            loader: 'babel',
            incude: path.join(__dirname, 'src'),
            query: {
                presets: [
                    require.resolve('babel-preset-es2015'),
                    require.resolve('babel-preset-react'),
                    require.resolve('babel-preset-stage-0')
                ]
            }
        }, {
            test: /\.tsx?$/,
            loader: 'ts',
            incude: path.join(__dirname, 'src')
        }, {
            test: /\.jsx?$/,
            incude: path.join(__dirname, 'src'),
            exclude: /node_modules/,
            loader: combineLoaders([
                {
                    loader: 'babel',
                    query: {
                        presets: [
                            require.resolve('babel-preset-es2015'),
                            require.resolve('babel-preset-react'),
                            require.resolve('babel-preset-stage-0')
                        ],
                        plugins: [
                            require.resolve('babel-plugin-syntax-class-properties'),
                            require.resolve('babel-plugin-transform-class-properties')
                        ]
                    }
                }
            ])
        }]
    },
    output: {
        filename: 'root.js',
        path: path.join(PROJECT_ROOT, 'dist'),
        publicPath: '/static/',
        library: 'SaplingComponent',
        libraryTarget: 'commonjs2'
    },
    resolve: {
        root: [ __dirname ],
        fallback: OUR_MODULES,
        extensions: ['', '.jsx', '.js', '.tsx', '.ts']
    },
    resolveLoader: {
        root: path.join(__dirname, 'node_modules'),
        fallback: OUR_MODULES
    }
}
