'use strict';

const os = require('os');
const path = require('path');
const fs = require('fs');
const spawn = require('child_process').spawn;
const execSync = require('child_process').execSync;
const rimraf = require('rimraf');
const sapling = require('./dist/sapling');

/*
   These tests run through the expected behavior of a built
   sapling project. They are not unit tests.
*/

describe('react-sapling integration tests', function() {

    this.timeout(60000 * 5);

    const rand = Math.floor(Math.random() * 9001);
    const tmp = os.tmpdir() + path.sep;
    const tsTmpDir = tmp + 'sapling-test-ts-' + rand;
    const jsTmpDir = tmp + 'sapling-test-js-' + rand;

    before(function() {
        this.timeout(60000 * 5);
        // Link `react-sapling` to the local npm
        execSync('npm link', { cwd: __dirname });

        // create a new react-sapling project dirs
        process.stdout.write('\nCreating tmp dirs...');
        fs.mkdirSync(tsTmpDir);
        fs.mkdirSync(jsTmpDir);
        process.stdout.write('done!');

        // init npm for the projects
        process.stdout.write('\nCreating package.json (npm init)...');
        execSync('npm init -y', { cwd: tsTmpDir });
        execSync('npm init -y', { cwd: jsTmpDir });
        process.stdout.write('done!');

        // link in react-sapling
        process.stdout.write('\nLinking react-sapling...');
        execSync('npm link react-sapling', { cwd: tsTmpDir });
        execSync('npm link react-sapling', { cwd: jsTmpDir });
        process.stdout.write('done!');

        process.stdout.write('\nInitilizing sapling component projects...');
        return Promise.all([
            sapling.initStatic(tsTmpDir, 'typescript', 'TestComponent'),
            sapling.initStatic(jsTmpDir, 'javascript', 'TestComponent')
        ]).then(() => {
            console.log('done!');
        });
    });

    after(function() {
        return Promise.all([
            new Promise((resolve, reject) => {
                rimraf(tsTmpDir, error => error ? reject(): resolve());
            }),
            new Promise((resolve, reject) => {
                rimraf(jsTmpDir, error => error ? reject(): resolve());
            })
        ]);
    });

    it('should run tests', function() {
        this.timeout(60000 * 10);

        return sapling.runTests(tsTmpDir).then(() => {
            return sapling.runTests(jsTmpDir);
        });
    });

    it('should run a build', () => {
        this.timeout(60000 * 10);
        return Promise.all([
            sapling.buildLibProd(tsTmpDir),
            sapling.buildLibProd(jsTmpDir)
        ]);
    });

    it('should build documentation', () => {
        this.timeout(60000 * 10);
        return Promise.all([
            sapling.buildLibDocs(tsTmpDir),
            sapling.buildLibDocs(jsTmpDir)
        ]);
    });

    it('should build documentation bundle', () => {
        this.timeout(60000 * 10);
        return Promise.all([
            sapling.buildBundleDocs(tsTmpDir),
            sapling.buildBundleDocs(jsTmpDir)
        ]);
    });

    it.skip('should run a dev server', () => {

    });
});
